# Please keep this package in sync with FC

%define dname	%{name}d

Name:		spice-vdagent
Version:	0.22.1
Release:	%mkrel 5
Summary:	Agent for Spice guests
Group:		System/X11
License:	GPLv3+
URL:            https://spice-space.org/
Source0:        https://spice-space.org/download/releases/%{name}-%{version}.tar.bz2
Source1:        https://spice-space.org/download/releases/%{name}-%{version}.tar.bz2.sig
Source2:        victortoso-E37A484F.keyring

# from git upstream (see https://gitlab.freedesktop.org/spice/linux/vd_agent)
Patch0001:	0001-Makefile.am-don-t-create-var-run-spice-vdagentd.patch
Patch0002:	0002-vdagent-Remove-watch-event-on-vdagent_display_destro.patch
Patch0003:	0003-Switch-to-spice-vdagent.service-by-default.patch

BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	spice-protocol >= 0.14.3
BuildRequires:	pkgconfig(pciaccess)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(xinerama)
BuildRequires:	pkgconfig(xfixes)
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(udev)
BuildRequires:	pkgconfig(libdrm)
BuildRequires:	libtool
BuildRequires:  gnupg2

Requires(post):	systemd >= %{systemd_required_version}
Requires(post):	rpm-helper >= %{rpmhelper_required_version}
Requires(preun): rpm-helper >= %{rpmhelper_required_version}

Provides:	%{name}-gdm = %{version}-%{release}
Obsoletes:	%{name}-gdm <= 0.16.0-3.mga6

%description
Spice agent for Linux guests offering the following features:

Features:
* Client mouse mode (no need to grab mouse by client, no mouse lag)
  this is handled by the daemon by feeding mouse events into the kernel
  via uinput. This will only work if the active X-session is running a
  spice-vdagent process so that its resolution can be determined.
* Automatic adjustment of the X-session resolution to the client resolution
* Support of copy and paste (text and images) between the active X-session
  and the client


%prep
gpgv2 --quiet --keyring %{SOURCE2} %{SOURCE1} %{SOURCE0}
%autosetup -p1
autoreconf -fi


%build
CFLAGS="%build_cflags -Wall -Werror"
%configure --with-session-info=systemd --with-init-script=systemd
%make_build V=2

%install
%make_install V=2

mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
cat > %{buildroot}%{_sysconfdir}/sysconfig/spice-vdagentd <<EOF
SPICE_VDAGENTD_EXTRA_ARGS=""
EOF

mkdir -p %{buildroot}%{_systemd_util_dir}/user-preset
cat > %{buildroot}%{_systemd_util_dir}/user-preset/91-spice-vdagent.preset <<EOF
enable spice-vdagent.service
EOF

%post
%systemd_post spice-vdagentd.service spice-vdagentd.socket

%preun
%systemd_preun spice-vdagentd.service spice-vdagentd.socket
%systemd_user_preun spice-vdagent.service
 
%postun
%systemd_postun_with_restart spice-vdagentd.service spice-vdagentd.socket

%posttrans
%systemd_user_post spice-vdagent.service
 
%files
%doc COPYING CHANGELOG.md README.md
%config(noreplace) %{_sysconfdir}/sysconfig/spice-vdagentd
%{_udevrulesdir}/70-spice-vdagentd.rules
%{_unitdir}/spice-vdagentd.service
%{_unitdir}/spice-vdagentd.socket
%{_userunitdir}/spice-vdagent.service
%{_tmpfilesdir}/spice-vdagentd.conf
%{_systemd_util_dir}/user-preset/91-spice-vdagent.preset
%{_bindir}/spice-vdagent
%{_sbindir}/spice-vdagentd
%{_sysconfdir}/xdg/autostart/spice-vdagent.desktop
# For /usr/share/gdm/autostart/LoginWindow/spice-vdagent.desktop
# We own the dir too, otherwise we must Require gdm
%{_datadir}/gdm
%{_mandir}/man1/%{name}*.1*


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 0.22.1-5.mga10
+ Revision: 2222185
- Mageia 10 Mass Rebuild

* Wed Apr 17 2024 ghibo <ghibo> 0.22.1-4.mga10
+ Revision: 2058336
- Fix SPICE_VDAGENTD_EXTRA_ARGS_NAME.
- Use noreplace for sysconfig file.

* Fri Apr 12 2024 ghibo <ghibo> 0.22.1-3.mga10
+ Revision: 2056711
- Bump release

* Fri Apr 12 2024 ghibo <ghibo> 0.22.1-2.5.mga10
+ Revision: 2056700
- Include patches from git upstream
- Drop fix for g_memdup deprecation, solved upstream (https://gitlab.freedesktop.org/spice/linux/vd_agent/-/merge_requests/35)
- Use %%systemd_post commands.
- Add /etc/sysconfig/spice-vdagentd.
- Specify CFLAGS as rpm flags were overridden.
- Provide a preset for spice-vdagent.service and enable for systemd --user globally (bug
- Sync with FC.

* Fri Sep 09 2022 neoclust <neoclust> 0.22.1-2.mga9
+ Revision: 1886091
- New version 0.22.1

* Thu Mar 31 2022 umeabot <umeabot> 0.22.0-2.mga9
+ Revision: 1837247
- Mageia 9 Mass Rebuild

* Wed Feb 16 2022 tv <tv> 0.22.0-1.mga9
+ Revision: 1778268
- Update to spice-vdagent 0.22.1

* Thu Oct 28 2021 tv <tv> 0.21.0-2.mga9
+ Revision: 1753217
- add user spice-vdgant.service (rhbz#1951580)
  use upstream-able patch (upstream merge request 37)

* Sun Feb 28 2021 tv <tv> 0.21.0-1.mga9
+ Revision: 1693330
- 0.21.0

* Sun Dec 27 2020 luigiwalser <luigiwalser> 0.20.0-4.mga8
+ Revision: 1664304
- remove unused variable
- add patches from ubuntu to fix CVE-2020-2565[0-3]

* Thu Mar 26 2020 tv <tv> 0.20.0-3.mga8
+ Revision: 1560824
- Fix agent shutdown (rhbz#1813667)

* Tue Mar 10 2020 tv <tv> 0.20.0-2.mga8
+ Revision: 1555371
- check the sources with gnupg2

* Tue Mar 10 2020 tv <tv> 0.20.0-1.mga8
+ Revision: 1555343
- Update to spice-vdagent 0.20.0

* Sun Feb 16 2020 umeabot <umeabot> 0.19.0-4.mga8
+ Revision: 1534839
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Oct 07 2019 tv <tv> 0.19.0-3.mga8
+ Revision: 1450168
- Backport clipboard-race patches (rhbz#1755038)

* Mon Sep 16 2019 tv <tv> 0.19.0-2.mga8
+ Revision: 1442146
- Add patch to lookup graphical session (rhbz#1750120)
  https://gitlab.freedesktop.org/spice/linux/vd_agent/merge_requests/2

* Mon Apr 22 2019 tv <tv> 0.19.0-1.mga7
+ Revision: 1394807
- new release

* Tue Mar 19 2019 martinw <martinw> 0.18.0-4.mga7
+ Revision: 1378964
- add first upstream patch to use /run instead of /var/run

* Sun Mar 17 2019 daviddavid <daviddavid> 0.18.0-3.mga7
+ Revision: 1378412
- add/rebase upstream patch to use /run instead of /var/run

* Mon Oct 01 2018 umeabot <umeabot> 0.18.0-2.mga7
+ Revision: 1314242
- Mageia 7 Mass Rebuild
+ tv <tv>
- new release

* Wed Jan 11 2017 tmb <tmb> 0.17.0-2.mga6
+ Revision: 1081034
- rebuild for missing package

* Tue Dec 06 2016 tv <tv> 0.17.0-1.mga6
+ Revision: 1072736
- switch to upstream systemd macros

* Thu Jun 16 2016 daviddavid <daviddavid> 0.16.0-5.mga6
+ Revision: 1021787
- add patch from debian to fix build with new systemd
- switch BRs to pkgconfig()

* Sat Apr 23 2016 tv <tv> 0.16.0-4.mga6
+ Revision: 1005771
- switch to upstream systemd macros
- merge back gdm subpackage into main package
- drop wrong requires on gdm

* Sat Apr 23 2016 tv <tv> 0.16.0-3.mga6
+ Revision: 1005562
- actually apply patches

* Sat Apr 23 2016 tv <tv> 0.16.0-2.mga6
+ Revision: 1005475
+ rebuild (emptylog)

* Sat Apr 23 2016 tv <tv> 0.16.0-1.mga6
+ Revision: 1005468
- new release

* Tue Feb 09 2016 umeabot <umeabot> 0.15.0-3.mga6
+ Revision: 952381
- Mageia 6 Mass Rebuild

* Thu Feb 19 2015 alien <alien> 0.15.0-2.mga5
+ Revision: 815802
- Fix service startup

* Wed Feb 18 2015 alien <alien> 0.15.0-1.mga5
+ Revision: 815667
- imported package spice-vdagent

